@@ -4,7 +4,7 @@
 /* packets.h
    Data structures and functions related to processing of received packets
 
-   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012, 2013 Eloy Paris
+   Copyright (C) 2007-2014 Eloy Paris
 
    This is part of Network Expect.
 
@@ -23,6 +23,10 @@
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
+#include <epan/epan.h>
+#include <epan/dfilter/dfilter.h>
+#include <epan/column-utils.h>
+
 /*
  * Tcl variable that will store the raw data of a decoded packet.
  * This variable is a Tcl BArray object.
@@ -41,6 +45,9 @@
  */
 #define DISSECTION_NS_VARNAME "dissection_ns"
 
+extern epan_t *epan;
+extern column_info cinfo; 
+
 extern void pkt_init(const char *);
 extern int pkt_show_dissection(Tcl_Interp *);
 extern int pkt_clear_dissection(Tcl_Interp *, int, Tcl_Obj * const *);
@@ -55,6 +62,4 @@ extern int pkt_isanswer(Tcl_Interp *,
 			const u_char *, struct wtap_pkthdr *, frame_data *,
 			const u_char *, struct wtap_pkthdr *, frame_data *);
 
-extern column_info cinfo; 
-
 #endif /* _PACKETS_H */
