@@ -3,7 +3,7 @@
    Interface with libwireshark for packet dissection. Packet dissection
    is launched from here but is ultimately performed by libwireshark.
 
-   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012, 2013 Eloy Paris
+   Copyright (C) 2007-2014 Eloy Paris
 
    Some code here has been borrowed from the Wireshark source code, and
    is copyright Gerald Combs and others.
@@ -119,8 +119,10 @@ proto_tree_tcl_node(proto_node *node, gpointer data)
 	    if (!fi->ds_tvb)
 		break;
 
-	    obj = Tcl_NewBArrayObj(ep_tvb_memdup(fi->ds_tvb, fi->start,
-						 fi->length),
+	    obj = Tcl_NewBArrayObj(tvb_memdup(wmem_epan_scope(),
+					      fi->ds_tvb,
+					      fi->start,
+					      fi->length),
 				   fi->length);
 	    _pkt_createvar(interp, varname, obj, cb_data->variables);
 
@@ -208,7 +210,10 @@ proto_tree_tcl_node(proto_node *node, gpointer data)
 	    a.addr_type = ADDR_TYPE_ETH;
 	    a.addr_bits = ETH_ADDR_BITS;
 	    memcpy(&a.addr_ip,
-		   ep_tvb_memdup(fi->ds_tvb, fi->start, fi->length),
+		   tvb_memdup(wmem_epan_scope(),
+			      fi->ds_tvb,
+			      fi->start,
+			      fi->length),
 		   ETH_ADDR_LEN);
 	    obj = Tcl_NewAddrObj(&a);
 	    _pkt_createvar(interp, varname, obj, cb_data->variables);
@@ -217,7 +222,10 @@ proto_tree_tcl_node(proto_node *node, gpointer data)
 	    a.addr_type = ADDR_TYPE_IP;
 	    a.addr_bits = IP_ADDR_BITS;
 	    memcpy(&a.addr_ip,
-		   ep_tvb_memdup(fi->ds_tvb, fi->start, fi->length),
+		   tvb_memdup(wmem_epan_scope(),
+			      fi->ds_tvb,
+			      fi->start,
+			      fi->length),
 		   IP_ADDR_LEN);
 	    obj = Tcl_NewAddrObj(&a);
 	    _pkt_createvar(interp, varname, obj, cb_data->variables);
@@ -226,7 +234,10 @@ proto_tree_tcl_node(proto_node *node, gpointer data)
 	    a.addr_type = ADDR_TYPE_IP6;
 	    a.addr_bits = IP6_ADDR_BITS;
 	    memcpy(&a.addr_ip,
-		   ep_tvb_memdup(fi->ds_tvb, fi->start, fi->length),
+		   tvb_memdup(wmem_epan_scope(),
+			      fi->ds_tvb,
+			      fi->start,
+			      fi->length),
 		   IP6_ADDR_LEN);
 	    obj = Tcl_NewAddrObj(&a);
 	    _pkt_createvar(interp, varname, obj, cb_data->variables);
@@ -244,8 +255,10 @@ proto_tree_tcl_node(proto_node *node, gpointer data)
 	case FT_UINT_BYTES: 
 	case FT_GUID:
 	case FT_OID:
-	    obj = Tcl_NewBArrayObj(ep_tvb_memdup(fi->ds_tvb, fi->start,
-						 fi->length),
+	    obj = Tcl_NewBArrayObj(tvb_memdup(wmem_epan_scope(),
+					      fi->ds_tvb,
+					      fi->start,
+					      fi->length),
 				   fi->length);
 	    _pkt_createvar(interp, varname, obj, cb_data->variables);
 	    break;
@@ -400,6 +413,10 @@ pkt_dissect_tcl(Tcl_Interp *interp, const u_char *packet,
     int passed;
     struct pcap_pkthdr pkt_hdr;
     char *varname;
+    tvbuff_t *tvb;
+
+    /* XXX -- need to properly dispose of this tvb. */
+    tvb = tvb_new_real_data(packet, fdata->pkt_len, fdata->cap_len);
 
     /*
      * Set up the Tcl namespace that will hold all the Tcl variables
@@ -408,14 +425,15 @@ pkt_dissect_tcl(Tcl_Interp *interp, const u_char *packet,
     if (ns_name && !Tcl_FindNamespace(interp, ns_name, NULL, TCL_GLOBAL_ONLY) )
 	Tcl_CreateNamespace(interp, ns_name, NULL, NULL);
 
-    edt = epan_dissect_new(1 /* create_proto_tree */,
+    edt = epan_dissect_new(epan,
+			   1 /* create_proto_tree */,
 			   1 /* proto_tree_visible */);
 
     if (rfcode)
 	epan_dissect_prime_dfilter(edt, rfcode);
 
     /* Outsource the heavy lifting to libwireshark */
-    epan_dissect_run(edt, wphdr, packet, fdata, NULL /* cinfo */);
+    epan_dissect_run(edt, 0, wphdr, tvb, fdata, NULL /* cinfo */);
 
     /* Run the read filter if we have one. */
     passed = rfcode ? dfilter_apply_edt(rfcode, edt) : 1;
@@ -668,12 +686,17 @@ pkt_dissect_show(const u_char *packet, struct wtap_pkthdr *wphdr,
 {
     epan_dissect_t *edt;
     struct callback_data_show cb_data;
+    tvbuff_t *tvb;
 
-    edt = epan_dissect_new(1 /* create_proto_tree */,
+    /* XXX -- need to properly dispose of this tvb. */
+    tvb = tvb_new_real_data(packet, fdata->pkt_len, fdata->cap_len);
+
+    edt = epan_dissect_new(epan,
+			   1 /* create_proto_tree */,
 			   1 /* proto_tree_visible */);
 
     /* Outsource the heavy lifting to libwireshark */
-    epan_dissect_run(edt, wphdr, packet, fdata, NULL /* cinfo */);
+    epan_dissect_run(edt, 0, wphdr, tvb, fdata, NULL /* cinfo */);
 
     /*
      * The packet has been dissected. Now print results.
