@@ -2,7 +2,7 @@
 
    Initialization of the libpackets subsystem.
 
-   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012 Eloy Paris <peloy@netexpect.org>
+   Copyright (C) 2007-2014 Eloy Paris <peloy@netexpect.org>
 
    Some code here has been borrowed from the Wireshark source code, and
    is copyright Gerald Combs and others.
@@ -28,23 +28,22 @@
 #include "config.h"
 #endif
 
+#include <stdlib.h>
 #include <string.h>
 #include <tcl.h>
+#include <epan/epan.h>
 #include <epan/timestamp.h>
 #include <epan/packet.h>
 #include <epan/column.h>
 #include <epan/prefs.h>
 #include <wsutil/privileges.h>
-#include <epan/filesystem.h>
+#include <wsutil/filesystem.h>
 
 #include "util-tcl.h"
+#include "packets.h"
 #include "packets-priv.h"
 
-/* These are used by epan_init() */
-static void read_failure_message(const char *, int);
-static void write_failure_message(const char *, int);
-static void failure_message(const char *, va_list);
-static void open_failure_message(const char *, int, gboolean);
+epan_t *epan;
 
 column_info cinfo;
 
@@ -88,8 +87,7 @@ init_libwireshark(const char *ws_conf_profile)
     timestamp_set_seconds_type(TS_SECONDS_DEFAULT);
 
     epan_init(register_all_protocols, register_all_protocol_handoffs,
-	      NULL, NULL, failure_message, open_failure_message,
-	      read_failure_message, write_failure_message);
+	      NULL, NULL);
 
     /*
      * Now register the preferences for any non-dissector modules.
@@ -156,36 +154,7 @@ init_libwireshark(const char *ws_conf_profile)
 	}
     }
 
-    /* Initialize all data structures used for dissection. */
-    init_dissection();
-}
-
-static void
-read_failure_message(const char *filename, int err)
-{
-    fprintf(stderr, "An error occurred while reading from the file \"%s\": %s.",
-	    filename, strerror(err) );
-}
-
-static void
-write_failure_message(const char *filename, int err)
-{
-    fprintf(stderr, "An error occurred while writing to the file \"%s\": %s.",
-	    filename, strerror(err) );
-}
-
-static void
-failure_message(const char *msg_format, va_list ap)
-{
-    vfprintf(stderr, msg_format, ap);
-    fprintf(stderr, "\n");
-}
-
-static void
-open_failure_message(const char *filename, int err, gboolean for_writing)
-{
-    fprintf(stderr, "open error. filename = %s, err = %d, for_writing = %d\n",
-	    filename, err, for_writing);
+    epan = epan_new();
 }
 
 /*
@@ -196,6 +165,7 @@ static void
 packets_cleanup(void)
 {
     g_hash_table_destroy(dissection_vars);
+    epan_free(epan);
     epan_cleanup();
 }
 
