@@ -31,11 +31,13 @@
 #endif
 
 #include <epan/epan_dissect.h>
+#include <wiretap/wtap.h>
 
 #include <string.h>
 #include <glib.h>
 #include <tcl.h>
 
+#include "packets.h"
 #include "proto_hier_stats.h"
 #include "tcl_packet.h"
 
@@ -136,10 +138,14 @@ process_frame(struct wtap_pkthdr *phdr, frame_data *frame, uint8_t *pkt,
 {
 	epan_dissect_t			*edt;
 	double				cur_time;
+        tvbuff_t *tvb;
+
+	/* XXX -- need to properly dispose of this tvb. */
+	tvb = tvb_new_real_data(pkt, frame->pkt_len, frame->cap_len);
 
 	/* Dissect the frame */
-	edt = epan_dissect_new(TRUE /* tree */, FALSE /* not visible */);
-	epan_dissect_run(edt, phdr, pkt, frame, NULL);
+	edt = epan_dissect_new(epan, TRUE /* tree */, FALSE /* not visible */);
+	epan_dissect_run(edt, 0, phdr, tvb, frame, NULL /* cinfo */);
 
 	/* Get stats from this protocol tree */
 	process_tree(edt->tree, ps, frame->pkt_len);
@@ -169,7 +175,7 @@ ph_stats_tcl(Tcl_Interp *interp, int objc, Tcl_Obj * const *objv)
     gboolean stop_flag;
     double cur_time;
     GTimeVal start_time;
-    Tcl_ObjType *listobjtype;
+    const Tcl_ObjType *listobjtype;
     Tcl_Obj *obj, **pkt_list;
     uint8_t *pkt;
     int i, j, llen;
