@@ -275,12 +275,9 @@ fill_in_pkthdr(struct wtap_pkthdr *phdr, const struct pcap_pkthdr *h,
 }
 
 static void
-//fill_in_framedata(frame_data *fdata, const struct pcap_pkthdr *h, int ll_type)
 fill_in_framedata(frame_data *fdata, struct wtap_pkthdr *phdr)
 {
     frame_data_init(fdata, 0 /* num */, phdr, 0 /* offset */, 0 /* cum_bytes */);
-
-    nstime_set_unset(&fdata->rel_ts);
 }
 
 /*
