@@ -5,7 +5,7 @@
    The "packet" and "ws" Tcl commands and the "packet" Tcl object type
    are implemented here.
 
-   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012, 2013 Eloy Paris
+   Copyright (C) 2007-2014 Eloy Paris <peloy@netexpect.org>
 
    Some code here has been borrowed from the Wireshark source code, and
    is copyright Gerald Combs and others.
@@ -31,6 +31,7 @@
 
 #include <assert.h>
 #include <epan/prefs.h>
+#include <epan/column-info.h>
 #include <epan/column-utils.h>
 #include <wiretap/pcap-encap.h> /* For wtap_pcap_encap_to_wtap_encap() */
 
@@ -140,8 +141,6 @@ static void
 fill_in_framedata(frame_data *fdata, struct wtap_pkthdr *phdr)
 {
     frame_data_init(fdata, 0 /* num */, phdr, 0 /* offset */, 0 /* cum_bytes */);
-
-    nstime_set_unset(&fdata->rel_ts);
 }
 
 /* From tshark.c:print_columns() */
@@ -173,7 +172,11 @@ char *columns_to_string(column_info *cinfo)
 	case COL_CLS_TIME:
 	case COL_REL_TIME:
 	case COL_ABS_TIME:
-	case COL_ABS_DATE_TIME: /* XXX - wider */
+	case COL_ABS_YMD_TIME:  /* XXX - wider */
+	case COL_ABS_YDOY_TIME: /* XXX - wider */
+	case COL_UTC_TIME:
+	case COL_UTC_YMD_TIME:  /* XXX - wider */
+	case COL_UTC_YDOY_TIME: /* XXX - wider */
 	    if (!print_ts)
 		continue;
 
@@ -359,6 +362,7 @@ update_string(Tcl_Obj *packet_obj)
     char *string_rep;
     frame_data fdata;
     struct wtap_pkthdr phdr;
+    tvbuff_t *tvb;
 
     packet = packet_obj->internalRep.otherValuePtr;
 
@@ -366,12 +370,16 @@ update_string(Tcl_Obj *packet_obj)
 
     fill_in_framedata(&fdata, &phdr);
 
-    edt = epan_dissect_new(0 /* create_proto_tree */,
+    /* XXX -- need to properly dispose of this tvb. */
+    tvb = tvb_new_real_data(packet->bytes.data, fdata.pkt_len, fdata.cap_len);
+
+    edt = epan_dissect_new(epan,
+			   0 /* create_proto_tree */,
                            0 /* proto_tree_visible */);
 
     col_custom_prime_edt(edt, &cinfo);
 
-    epan_dissect_run(edt, &phdr, packet->bytes.data, &fdata, &cinfo);
+    epan_dissect_run(edt, 0, &phdr, tvb, &fdata, &cinfo);
 
     epan_dissect_fill_in_columns(edt, FALSE, TRUE);
 
@@ -1133,6 +1141,8 @@ NExp_PacketObjCmd(ClientData clientData _U_, Tcl_Interp *interp, int objc,
     case SUBCMD_LENGTH:
 	retval = tcl_packet_len(interp, objc - 1, &objv[1]);
 	break;
+    default:
+	retval = TCL_ERROR;
     }
 
     return retval;
@@ -1200,6 +1210,8 @@ NExp_WSObjCmd(ClientData clientData _U_, Tcl_Interp *interp, int objc,
     case SUBCMD_SETPREF:
 	retval = tcl_ws_setprefs(interp, objc - 1, &objv[1]);
 	break;
+    default:
+	retval = TCL_ERROR;
     }
 
     return retval;
